%global srcname PyYAML

Name:           python3-%{srcname}
Version:        3.11
Release:        4%{?dist}
Summary:        YAML parser and emitter for Python 3

License:        MIT
URL:            http://pyyaml.org/
Source0:        http://pyyaml.org/download/pyyaml/%{srcname}-%{version}.tar.gz
# It actually uses python2 Cython to build _yaml.c
BuildRequires:  Cython
BuildRequires:  libyaml-devel
BuildRequires:  python2-devel
# debian patch, upstream ticket http://pyyaml.org/ticket/247 and
# https://bitbucket.org/xi/pyyaml/issue/35/test-fails-on-be-s390-x-ppc64
Patch0: debian-big-endian-fix.patch

# CVE-2014-9130 assert failure when processing wrapped strings
# https://bugzilla.redhat.com/show_bug.cgi?id=1204829
Patch1: PyYAML-CVE-2014-9130.patch

%description
YAML is a data serialization format designed for human readability and
interaction with scripting languages.  PyYAML is a YAML parser and
emitter for Python 3.

PyYAML features a complete YAML 1.1 parser, Unicode support, pickle
support, capable extension API, and sensible error messages.  PyYAML
supports standard YAML tags and provides Python-specific tags that
allow to represent an arbitrary Python object.

PyYAML is applicable for a broad range of tasks from complex
configuration files to object serialization and persistance.

%package -n python%{python3_pkgversion}-%{srcname}
Summary: YAML parser and emitter for Python %{python3_version}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
Provides: python%{python3_pkgversion}-yaml = %{version}-%{release}
Provides: python%{python3_pkgversion}-yaml%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname}
YAML is a data serialization format designed for human readability and
interaction with scripting languages.  PyYAML is a YAML parser and
emitter for Python %{python3_version}.

PyYAML features a complete YAML 1.1 parser, Unicode support, pickle
support, capable extension API, and sensible error messages.  PyYAML
supports standard YAML tags and provides Python-specific tags that
allow to represent an arbitrary Python object.

PyYAML is applicable for a broad range of tasks from complex
configuration files to object serialization and persistance.

%if 0%{?python3_other_pkgversion}
%package -n python%{python3_other_pkgversion}-%{srcname}
Summary: YAML parser and emitter for Python %{python3_version}
BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-setuptools
Provides: python%{python3_other_pkgversion}-yaml = %{version}-%{release}
Provides: python%{python3_other_pkgversion}-yaml%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python%{python3_other_pkgversion}-%{srcname}}

%description -n python%{python3_other_pkgversion}-%{srcname}
YAML is a data serialization format designed for human readability and
interaction with scripting languages.  PyYAML is a YAML parser and
emitter for Python %{python3_version}.

PyYAML features a complete YAML 1.1 parser, Unicode support, pickle
support, capable extension API, and sensible error messages.  PyYAML
supports standard YAML tags and provides Python-specific tags that
allow to represent an arbitrary Python object.

PyYAML is applicable for a broad range of tasks from complex
configuration files to object serialization and persistance.
%endif # python3_other_pkgversion


%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1 -b .be
chmod a-x examples/yaml-highlight/yaml_hl.py

%patch1 -p1

# remove pre-generated file
rm -rf ext/_yaml.c


%build
# regenerate ext/_yaml.c with python2/Cython
CFLAGS="${RPM_OPT_FLAGS}" %{__python2} setup.py --with-libyaml build_ext
CFLAGS="${RPM_OPT_FLAGS}" %{__python3} setup.py --with-libyaml build
%{?python3_other_pkgversion: CFLAGS="${RPM_OPT_FLAGS}" %{__python3_other} setup.py --with-libyaml build}


%install
%py3_install
%{?python3_other_pkgversion: %py3_other_install}


%check
%{__python3} setup.py test
%{?python3_other_pkgversion: %{__python3_other} setup.py test}


%files -n python%{python3_pkgversion}-%{srcname}
%license LICENSE
%doc CHANGES README examples
%{python3_sitearch}/*


%if 0%{?python3_other_pkgversion}
%files -n python%{python3_other_pkgversion}-%{srcname}
%license LICENSE
%doc CHANGES README examples
%{python3_other_sitearch}/*
%endif # python3_other_pkgversion


%changelog
* Thu Mar 07 2019 Troy Dawson <tdawson@redhat.com>
- Rebuilt to change main python from 3.4 to 3.6

* Wed Jan 16 2019 Scott K Logan <logans@cottsay.net> - 3.11-3
- Add Python 3.6 sub-package to EPEL7

* Thu Jan 14 2016 Orion Poplawski <orion@cora.nwra.com> - 3.11-2
- Clean up spec, mention python version

* Wed Dec 30 2015 Orion Poplawski <orion@cora.nwra.com> - 3.11-1
- Initial EPEL7 package
